@@ -76,39 +76,36 @@ class DjangoBasicResourceApiDispatcher(ResourceApiDispatcher):
         auth_allowed = self.iam.is_basic_auth_allowed(self.system, auth)
 
         if not auth_allowed:
-            logger.error("resource request({}) auth failed with auth param: {}".format(request_id, auth))
+            logger.error("resource request(%s) auth failed with auth param: %s", request_id, auth)
             return fail_response(401, "basic auth failed", request_id)
 
         # load json data
         try:
             data = json.loads(request.body)
         except Exception:
-            logger.error("resource request({}) failed with invalid body: {}".format(request_id, request.body))
+            logger.error("resource request(%s) failed with invalid body: %s", request_id, request.body)
             return fail_response(400, "reqeust body is not a valid json", request_id)
 
         # check basic params
         method = data.get("method")
         resource_type = data.get("type")
         if not (method and resource_type):
-            logger.error("resource request({}) failed with invalid data: {}".format(request_id, data))
+            logger.error("resource request(%s) failed with invalid data: %s. method and type required",
+                         request_id, data)
             return fail_response(400, "method and type is required field", request_id)
 
         # check resource type
         if resource_type not in self._provider:
-            logger.error(
-                "resource request({}) failed with unsupport resource type: {}".format(request_id, resource_type)
-            )
-            return fail_response(404, "unsupport resource type: {}".format(resource_type), request_id)
+            logger.error("resource request(%s) failed with unsupported resource type: %s", request_id, resource_type)
+            return fail_response(404, "unsupported resource type: {}".format(resource_type), request_id)
 
         # check method and process
         processor = getattr(self, "_dispatch_{}".format(method), None)
         if not processor:
-            logger.error("resource request({}) failed with unsupport method: {}".format(request_id, method))
-            return fail_response(404, "unsupport method: {}".format(method), request_id)
+            logger.error("resource request(%s) failed with unsupported method: %s", request_id, method)
+            return fail_response(404, "unsupported method: {}".format(method), request_id)
 
-        logger.info(
-            "resource request({}) with filter: {}, page: {}".format(request_id, data.get("filter"), data.get("page"))
-        )
+        logger.info("resource request(%s) with filter: %s, page: %s", request_id, data.get("filter"), data.get("page"))
         try:
             return processor(request, data, request_id)
         except InvalidPageException as e:
@@ -116,7 +113,7 @@ class DjangoBasicResourceApiDispatcher(ResourceApiDispatcher):
         except KeywordTooShortException as e:
             return fail_response(406, str(e), request_id)
         except Exception as e:
-            logger.exception("resource request({}) failed with exception: {}".format(request_id, e))
+            logger.exception("resource request(%s) failed with exception: %s", request_id, e)
             return fail_response(500, str(e), request_id)
 
     def _get_options(self, request):
